complete -c ssh-openpgp-auth -n "__fish_use_subcommand" -s h -l help -d 'Print help'
complete -c ssh-openpgp-auth -n "__fish_use_subcommand" -f -a "authenticate" -d 'Fetches OpenPGP host certificates, verifies it and prints host keys in SSH format on successful verification'
complete -c ssh-openpgp-auth -n "__fish_use_subcommand" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c ssh-openpgp-auth -n "__fish_seen_subcommand_from authenticate" -s t -l time -d 'Certificate time. By default now. Example: 2021-11-21T11:11:11Z' -r
complete -c ssh-openpgp-auth -n "__fish_seen_subcommand_from authenticate" -s c -l cert-store -d 'Certificate store. By default uses user\'s shared PGP certificate directory' -r -F
complete -c ssh-openpgp-auth -n "__fish_seen_subcommand_from authenticate" -l nameserver -d 'Nameserver to use for DNS lookups (if enabled)' -r
complete -c ssh-openpgp-auth -n "__fish_seen_subcommand_from authenticate" -l verify-dns-proof -d 'Verify Keyoxide DNS proofs of certificates'
complete -c ssh-openpgp-auth -n "__fish_seen_subcommand_from authenticate" -l verify-wot -d 'Verify the certificates using local Web of Trust network'
complete -c ssh-openpgp-auth -n "__fish_seen_subcommand_from authenticate" -l verbose -d 'Print details of the verification process. Useful for debugging'
complete -c ssh-openpgp-auth -n "__fish_seen_subcommand_from authenticate" -l store-verifications -d 'Store verification results in the OpenPGP certificate'
complete -c ssh-openpgp-auth -n "__fish_seen_subcommand_from authenticate" -s h -l help -d 'Print help'
complete -c ssh-openpgp-auth -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from authenticate; and not __fish_seen_subcommand_from help" -f -a "authenticate" -d 'Fetches OpenPGP host certificates, verifies it and prints host keys in SSH format on successful verification'
complete -c ssh-openpgp-auth -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from authenticate; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
